/* "double time" problem C - ACM NZ92
  Rewritten to C by Marian Varga  31-Mar-2000 */

#include <stdio.h>
#include <string.h>

char *dayname[] = {
"Sunday",
"Monday",
"Tuesday",
"Wednesday",
"Thursday",
"Friday",
"Saturday" };
char *monthname[] = {
"January",
"February",
"March",
"April",
"May",
"June",
"July",
"August",
"September",
"October",
"November",
"December" };
int commonmonths[] = { 0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334 };
int leapmonths[] = { 0, 31, 60, 91, 121, 152, 182, 213, 244, 274, 305, 335 };

short yearstart[2100], yearstartp[2100];
char dataday[50];
int datadayno, datadate, outputdate;
char datamonth[50];
int datamonthno, outputmonthno, datayear, outputyear;
int *monthtab;

int ReadData(void);
void SolveProblem(void);
void Initialise(void);
void RunBackwards(void);
void RunForwards(void);
void DoOldCalendar(void);
int NewLeap(int year);
int OldLeap(int year);
int NewToOld(void);
int OldToNew(void);


int main(void) {
  Initialise();
  while (ReadData()) {
    SolveProblem();
  }
  return 0;
}

int ReadData(void) {
  char s[256], t[256];
  int ok;

  ok=scanf("%s %d %s %d", dataday, &datadate, datamonth, &datayear);
  if (ok != 4) return 0;
  for (datadayno = 0;
       datadayno < 7 && strcmp(dataday, dayname[datadayno]); ++datadayno);
  for (datamonthno = 0;
       datamonthno < 12 && strcmp(datamonth, monthname[datamonthno]); ++datamonthno);
  /* printf("%d %d %d %d\n", datadayno, datadate, datamonthno, datayear); */
  return 1;
}

void SolveProblem(void) {
  if (NewToOld())
    printf("%s %d* %s %d\n",
      dataday, outputdate, monthname[outputmonthno], outputyear);
  else if (OldToNew())
    printf("%s %d %s %d\n",
      dataday, outputdate, monthname[outputmonthno], outputyear);
  else printf("Invalid Date\n");
}

void Initialise(void) {
  RunBackwards(); RunForwards();
  DoOldCalendar();
}

int NewLeap(int year) {
  return (year % 4 == 0 && (year % 100 != 0 || year % 400 == 0));
}

int OldLeap(int year) {
  return (year % 4 == 0);
}

int NewToOld(void) {
  int delta, today, dayno;

  delta = (yearstartp[datayear] - yearstart[datayear] + 7) % 7 + 7;
  if (NewLeap(datayear))  monthtab = leapmonths;
  else monthtab = commonmonths;
  today = monthtab[datamonthno] + datadate;
  dayno = (today + yearstart[datayear] - 1) % 7;
  if (datadayno == dayno) {
    today -= delta;
    if (today < 0) outputyear = datayear - 1;
    else outputyear = datayear;
    if (OldLeap(outputyear)) monthtab = leapmonths;
    else monthtab = commonmonths;
    if (today < 0) today = today + 365 + OldLeap(outputyear);
    outputmonthno = 11;
    while (monthtab[outputmonthno] > today) --outputmonthno;
    outputdate = today - monthtab[outputmonthno];
    return 1;
  }
  else return 0;
}

int OldToNew(void) {
  int delta, today, daysinyear, dayno;

  delta = (yearstartp[datayear] - yearstart[datayear] + 7) % 7 + 7;
  if (OldLeap(datayear)) monthtab = leapmonths;
  else monthtab = commonmonths;
  today = monthtab[datamonthno] + datadate;
  dayno = (today + yearstartp[datayear] - 1) % 7;
  if (datadayno == dayno) {
    today += delta;
    daysinyear = 365 + OldLeap(datayear);
    if (today > daysinyear) {
      outputyear = datayear + 1;
      today = today - daysinyear;
    }
    else outputyear = datayear;
    if (OldLeap(outputyear)) monthtab = leapmonths;
    else monthtab = commonmonths;
    outputmonthno = 11;
    while (monthtab[outputmonthno] > today) --outputmonthno;
    outputdate = today - monthtab[outputmonthno];
    return 1;
  }
  else return 0;
}

int NewPrev(int d, int y) {
  return (d - 1 - NewLeap(y) + 7) % 7;
}

int NewNext(int d, int y) {
  return (d + 1 + NewLeap(y)) % 7;
}

int OldNext(int d, int y) {
  return (d + 1 + OldLeap(y)) % 7;
}

void RunBackwards(void) {
  int year, d;

  d = 3; year = 1992; yearstart[1992] = d;  /* 1 January 1992 is Wednesday */

  for (year = 1991; year >= 1600;  year--) {
    d = NewPrev(d, year);
    yearstart[year] = d;
  }
}


void RunForwards(void) {
  int year, d;

  d = NewNext(yearstart[1992], 1992);
  for (year = 1993; year <= 2099; year++) {
    yearstart[year] = d;
    d = NewNext(d, year);
  }
}

void DoOldCalendar(void) {
  int year, dp;

  dp = (yearstart[1600] + 10) % 7;  /* They lost 10 days */
  for (year = 1600; year <= 2099; year++) {
    yearstartp[year] = dp;
    dp = OldNext(dp, year);
  }
}

