/* "Trees_a_Crowd" - NZ ACM contest 1992
   Sample solution rewritten to C by Marian Varga 1-Apr-2000 */

#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <math.h>

#define MAXTREES  6000  /* ultimately about 6,000 - enuf for now */
#define CMAX  11
#define RANGE  1   /* distance away of searched voxels */
#define RTOP  15  /* voxels  1 .. rtop+1 */
#define FAC  16 /* 256 div (rtop+1) */
#define TOOFAR 30000

short tree[MAXTREES][3];
short next[MAXTREES];
short minc[MAXTREES];
short box[RTOP+1+2*RANGE][RTOP+1+2*RANGE][RTOP+1+2*RANGE];
int n;
int h[CMAX+1], cut[CMAX+1];
int c, f;

void Initialise(void);
void ReadTrees(void);
void FindDistances(void);
void FindHistogram(void);

int main(void) {
  Initialise();
  ReadTrees();
  FindDistances();
  FindHistogram();

  for (c = 0; c <= 9; c++) printf("%4d", h[c]);
  printf("\n");
  fclose(stdin);
}

void Initialise(void) {
  int x, y, z, d;

  for (c = 0;  c <= CMAX; c++) cut[c] = c*c;
  cut[CMAX] = TOOFAR;
}

void ReadTrees(void) {
  int i,j,k;
  int x, y, z;

  n= 0;
  for(;;) {
    scanf("%d%d%d", &i,&j,&k);
    if (i == 0 && j == 0 && k == 0) return;
    n++;
    tree[n][0] = i; tree[n][1] = j; tree[n][2] = k;
    minc[n] = CMAX;
    x = i / FAC + 1; y = j / FAC + 1; z = k / FAC + 1;
    next[n] = box[x][y][z]; box[x][y][z] = n;
  }
}

int dist(int i, int j) {
  int sum,d[3], k;

  for (k = 0; k<3; k++) {
    d[k] = tree[i][k] - tree[j][k];
    if (d[k] > 10 || d[k] < -10) return TOOFAR;
  }
  sum= 0;
  for (k = 0; k<3; k++) sum+= d[k]*d[k];
  return sum;
}


void Bump(int i, int d) {
  int k;

  k = CMAX;
  while (d < cut[k]) k--;
  if (k < minc[i]) minc[i] = k;
}

void FindDistances(void) {
  int x, y, z;
  int xs, ys, zs;
  int xe, ye, ze;
  int xp, yp, zp;
  int i,j;
  int d;

  for (x = 1; x<=RTOP+1; x++)
    for (y = 1; y<=RTOP+1; y++)
      for (z = 1; z<=RTOP+1; z++) {
        xs = x-RANGE; ys = y-RANGE; zs = z-RANGE;
        xe = x+RANGE; ye = y+RANGE; ze = z+RANGE;
        i = box[x][y][z];
        while (i != 0) {
          for (xp = xs; xp <= xe; xp++)
            for (yp = ys; yp <= ye; yp++)
              for (zp = zs; zp <= ze; zp++) {
                j = box[xp][yp][zp];
                while (j != 0) {
                  if (i != j) {
                    d = dist(i,j); Bump(i, d); Bump(j, d);
                  }
                  j = next[j];
                }
              }
          i = next[i];
        }
      }
}

void FindHistogram(void) {
  int i;

  for (i = 1; i<=n; i++) ++h[minc[i]];
}

