/*
 "Find the root!" by Marian Varga, 4-Apr-2000
*/
#include <stdio.h>
#include <stdlib.h>

#define BASE 1000
#define MAXDIG3 1000
typedef struct bigint {
  short dig[MAXDIG3];
  short n_digs;
} bigint;

void bigint_read(bigint *x) {
  static char buf[MAXDIG3*3+4];
  char *p, *bs=buf+3;
  short *dp = x->dig;

  buf[0]=buf[1]=buf[2]='0';
  scanf("%s", bs);
  p=buf+strlen(buf);
  while (p >= bs) {
    p-=3;
    *dp++ = atoi(p);
    *p='\0';
  }
  while (dp > x->dig && !dp[-1]) dp--;
  x->n_digs = dp - x->dig;
}

int bigint_iszero(bigint *x) { return x->n_digs == 0; }
void bigint_setzero(bigint *x) { x->n_digs = 0; }

void bigint_copy(bigint *src, bigint *dst) {
  short i;

  dst->n_digs=src->n_digs;
  for (i=0; i<src->n_digs; i++) dst->dig[i]=src->dig[i];
}

void bigint_add(bigint *a, bigint *b, bigint *s) {
  short i, mindigs, carry, s1;
  bigint *rest;

  if (a->n_digs < b->n_digs) { mindigs = a->n_digs; rest=b; }
  else { mindigs = b->n_digs; rest=a; }

  carry = 0;
  for (i=0; i<mindigs; i++) {
    s1 = a->dig[i] + b->dig[i] + carry;
    if (s1 >= BASE) { carry=1; s1-=BASE; }
    else carry=0;
    s->dig[i]=s1;
  }

  for (; i < rest->n_digs; i++) {
    s1 = rest->dig[i] + carry;
    if (s1 >= BASE) { carry=1; s1-=BASE; }
    else carry=0;
    s->dig[i]=s1;
  }

  if (carry) { s->dig[i++] = 1; }
  s->n_digs = i;
}

void bigint_halve(bigint *whole, bigint *half) {
  short carry, i;

  carry=0;
  for (i = whole->n_digs - 1; i>=0; i--) {
    half->dig[i] = (whole->dig[i] >> 1) + carry;
    carry = (whole->dig[i] & 1) ? BASE/2 : 0;
  }
  half->n_digs = whole->n_digs;
  if (half->n_digs && !half->dig[half->n_digs - 1]) half->n_digs--;
}

int bigint_compare(bigint *a, bigint *b) {
  short i;

  /** printf("cmp adigs=%d bdigs=%d",a->n_digs, b->n_digs); **/
  if (a->n_digs != b->n_digs) return (a->n_digs - b->n_digs);
  for (i=a->n_digs-1; i>=0; i--) {
    /** printf("cmp i=%d\n", i); **/
    if (a->dig[i] != b->dig[i]) return (a->dig[i] - b->dig[i]);
  }
  return 0;
}

void bigint_print(bigint*);
void bigint_multiply(bigint *a, bigint *b, bigint *p) {
  short i, j;
  int p1, carry;
  static bigint p2, p3;
  bigint *pp1=p, *pp2 = &p2, *pp3 = &p3, *pptmp;

  bigint_setzero(pp1);
  for (i=0; i < a->n_digs; i++) {
    if (!a->dig[i]) continue;
    carry=0;
    for (j=0; j < i; j++) pp2->dig[j]=0;
    for (j=0; j < b->n_digs; j++) {
      p1 = (int)a->dig[i] * (int)b->dig[j] + carry;
      pp2->dig[i+j] = p1 % BASE;
      carry = p1 / BASE;
    }
    if (carry) { pp2->dig[i+(j++)] = carry; }
    pp2->n_digs = i+j;
    /** printf("submul: "); bigint_print(pp2); printf("\n");  **/
    bigint_add(pp1, pp2, pp3);
    /** printf("subtot: "); bigint_print(pp3); printf("\n");  **/
    pptmp=pp1; pp1=pp3; pp3=pptmp;
  }
  bigint_copy(pp1, p);
}

void bigint_print(bigint *x) {
  short i;

  if (bigint_iszero(x)) { printf("0"); return; }
  printf("%d", x->dig[i=x->n_digs-1]);
  for (i--; i>=0; i--)
    printf("%03d", x->dig[i]);
}

bigint x, a, b, sum, c, y;

int main() {
  int res;

  for (;;) {
    bigint_read(&x);
    if (bigint_iszero(&x)) break;
    if (x.n_digs == 1 && x.dig[0] == 1) { printf("1\n"); continue; }

    bigint_setzero(&a); bigint_copy(&x, &b); /* initial lower and upper bounds */
    for (;;) {
      /** printf("a="); bigint_print(&a); **/
      /** printf("\nb="); bigint_print(&b); printf("\n"); **/
      bigint_add(&a, &b, &sum);
      /** printf("sum="); bigint_print(&sum); printf("\n"); **/
      bigint_halve(&sum, &c);  /* c = (a+b)/2 */
      /** printf("c="); bigint_print(&c); printf("\n"); **/
      if (!bigint_compare(&c, &a)) break;
      bigint_multiply(&c, &c, &y);   /* y = c ^ 2 */
      /** printf("y="); bigint_print(&y); printf("\n"); **/
      res = bigint_compare(&y, &x);
      if (res < 0) { bigint_copy(&c, &a); }
      else if (res > 0) { bigint_copy(&c, &b); }
      else break;
    }
    bigint_print(&c);
    printf("\n");
  }
  return 0;
}
